aboutsummaryrefslogtreecommitdiffstats
path: root/qt-models/filtermodels.cpp
diff options
context:
space:
mode:
authorGravatar Robert C. Helling <helling@atdotde.de>2020-03-11 11:30:51 +0100
committerGravatar Dirk Hohndel <dirk@hohndel.org>2020-03-11 08:26:30 -0700
commit285fa8acbceebf5dc87c5c3befe42a2917a3b844 (patch)
tree142efc52856b5f4bded40867a917800c241ebfb6 /qt-models/filtermodels.cpp
parentcb28158b9abe10f08142f12f11ddbb5d23686fd5 (diff)
downloadsubsurface-285fa8acbceebf5dc87c5c3befe42a2917a3b844.tar.gz
Grammar: replaces 'indexes' by 'indices'
Grammar-nazi ran git grep -l 'indexes' | xargs sed -i '' -e 's/indexes/indices/g' to prevent future wincing when reading the source code. Unfortunatly, Qt itself is infected as in QModelIndexList QItemSelection::indexes() const Signed-off-by: Robert C. Helling <helling@atdotde.de>
Diffstat (limited to 'qt-models/filtermodels.cpp')
-rw-r--r--qt-models/filtermodels.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/qt-models/filtermodels.cpp b/qt-models/filtermodels.cpp
index 8d3cb800a..2d081e6e6 100644
--- a/qt-models/filtermodels.cpp
+++ b/qt-models/filtermodels.cpp
@@ -36,20 +36,20 @@ void MultiFilterSortModel::clear()
model->clear();
}
-// Translate selection into local indexes and re-emit signal
-void MultiFilterSortModel::selectionChangedSlot(const QVector<QModelIndex> &indexes)
+// Translate selection into local indices and re-emit signal
+void MultiFilterSortModel::selectionChangedSlot(const QVector<QModelIndex> &indices)
{
- QVector<QModelIndex> indexesLocal;
- indexesLocal.reserve(indexes.size());
- for (const QModelIndex &index: indexes) {
+ QVector<QModelIndex> indicesLocal;
+ indicesLocal.reserve(indices.size());
+ for (const QModelIndex &index: indices) {
QModelIndex local = mapFromSource(index);
if (local.isValid())
- indexesLocal.push_back(local);
+ indicesLocal.push_back(local);
}
- emit selectionChanged(indexesLocal);
+ emit selectionChanged(indicesLocal);
}
// Translate current dive into local indexes and re-emit signal
void MultiFilterSortModel::currentDiveChangedSlot(QModelIndex index)
{
QModelIndex local = mapFromSource(index);
@@ -36,20 +36,20 @@ void MultiFilterSortModel::clear()
}
-// Translate current dive into local indexes and re-emit signal
+// Translate current dive into local indices and re-emit signal
void MultiFilterSortModel::currentDiveChangedSlot(QModelIndex index)
{